==> wagtail-6.0.1.tar.gz: wagtail-6.0.1/SPONSORS.md <==
# Sponsors

The following organisations and individuals supported the [Wagtail's First Hatch](https://www.kickstarter.com/projects/noripyt/wagtails-first-hatch) crowdfunding campaign:

-   [Springload](https://springload.nz/)
-   [NetFM](https://netfm.org/)
-   [Ambient Innovation](https://ambient-innovation.com/)
-   [Shenberger Technology](https://shenbergertech.com/)
-   [Type/Code](https://typecode.com/)
-   [SharperTool](https://sharpertool.com/)
-   [Overcast Software](https://www.overcast.io/)
-   [Octave](https://octave.nz/)
-   [Taywa](https://www.taywa.ch/)
-   [Rock Kitchen Harris](https://www.rkh.co.uk/)
-   [The Motley Fool](https://www.fool.com/)
-   [R Strother Scott](https://twitter.com/rstrotherscott)
-   [Beyond Media](https://www.beyond.works/)

The features below were developed thanks to the sponsorship of these organsations:

-   Collections for images and documents - [University of South Wales](https://www.southwales.ac.uk/)

-   Display of revision differences - [Blackstone Chambers](https://www.blackstonechambers.com/)

-   Privacy settings on collections of documents - [Wharton Research Data Services](https://www.WhartonWRDS.com/) of [The Wharton School](https://www.wharton.upenn.edu)

-   Hooks for overriding menu actions - [The Motley Fool](https://www.fool.com/)

-   Improved page locking - [The Motley Fool](https://www.fool.com/)

-   Exporting data from reports, form submissions and ModelAdmin - [The Motley Fool](https://www.fool.com/)

-   Moderation workflow - [The Motley Fool](https://www.fool.com/)

-   Complex search queries - [The Motley Fool](https://www.fool.com/)

-   Multi-lingual content - [Torchbox](https://torchbox.com/wagtail-cms/) and [The Mozilla Foundation](https://foundation.mozilla.org/en/)

-   Page aliases - [The Mozilla Foundation](https://foundation.mozilla.org/en/)

-   Hooks for Snippet customisation - [The Mozilla Foundation](https://foundation.mozilla.org/en/)

-   Utility for testing hooks - [The Mozilla Foundation](https://foundation.mozilla.org/en/)

-   Telepath for StreamField editing - [YouGov](https://yougov.co.uk/)

-   Commenting - [The Motley Fool](https://www.fool.com/)

-   Automatic redirect creation - [The National Archives](https://www.nationalarchives.gov.uk)

-   Persistent IDs for ListBlock items - [NHS](https://www.nhs.uk/)

-   Page editor redesign - [Google](https://google.com/)

-   StreamField rich text block splitter - [The Motley Fool](https://www.fool.com/)

==> wagtail-6.4.1.tar.gz: wagtail-6.4.1/SPONSORS.md <==
# Sponsors

The following organisations and individuals supported the [Wagtail's First Hatch](https://www.kickstarter.com/projects/noripyt/wagtails-first-hatch) crowdfunding campaign:

-   [Springload](https://springload.nz/)
-   [NetFM](https://netfm.org/)
-   [Ambient Innovation](https://ambient-innovation.com/)
-   [Shenberger Technology](https://shenbergertech.com/)
-   [Type/Code](https://typecode.com/)
-   [SharperTool](https://sharpertool.com/)
-   [Overcast Software](https://www.overcast.io/)
-   [Octave](https://octave.nz/)
-   [Taywa](https://www.taywa.ch/)
-   [Rock Kitchen Harris](https://www.rkh.co.uk/)
-   [The Motley Fool](https://www.fool.com/)
-   [R Strother Scott](https://x.com/rstrotherscott)
-   [Beyond Media](https://www.beyond.works/)

The features below were developed thanks to the sponsorship of these organsations:

-   Collections for images and documents - [University of South Wales](https://www.southwales.ac.uk/)

-   Display of revision differences - [Blackstone Chambers](https://www.blackstonechambers.com/)

-   Privacy settings on collections of documents - [Wharton Research Data Services](https://www.WhartonWRDS.com/) of [The Wharton School](https://www.wharton.upenn.edu)

-   Hooks for overriding menu actions - [The Motley Fool](https://www.fool.com/)

-   Improved page locking - [The Motley Fool](https://www.fool.com/)

-   Exporting data from reports, form submissions and ModelAdmin - [The Motley Fool](https://www.fool.com/)

-   Moderation workflow - [The Motley Fool](https://www.fool.com/)

-   Complex search queries - [The Motley Fool](https://www.fool.com/)

-   Multi-lingual content - [Torchbox](https://torchbox.com/wagtail-cms/) and [The Mozilla Foundation](https://foundation.mozilla.org/en/)

-   Page aliases - [The Mozilla Foundation](https://foundation.mozilla.org/en/)

-   Hooks for Snippet customization - [The Mozilla Foundation](https://foundation.mozilla.org/en/)

-   Utility for testing hooks - [The Mozilla Foundation](https://foundation.mozilla.org/en/)

-   Telepath for StreamField editing - [YouGov](https://yougov.co.uk/)

-   Commenting - [The Motley Fool](https://www.fool.com/)

-   Automatic redirect creation - [The National Archives](https://www.nationalarchives.gov.uk)

-   Persistent IDs for ListBlock items - [NHS](https://www.nhs.uk/)

-   Page editor redesign - [Google](https://google.com/)

-   StreamField rich text block splitter - [The Motley Fool](https://www.fool.com/)
